@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction::App::FromProto;
-$XML::Grammar::Fiction::App::FromProto::VERSION = '0.30.0';
+$XML::Grammar::Fiction::App::FromProto::VERSION = '0.32.0';
 use strict;
 use warnings;
 use autodie;
@@ -10,9 +10,6 @@ our @EXPORT = (qw(run));
 
 use Getopt::Long qw/ GetOptions /;
 
-use XML::Grammar::Fiction::FromProto              ();
-use XML::Grammar::Fiction::FromProto::Parser::QnD ();
-
 
 sub run
 {
@@ -25,6 +22,8 @@ sub run
         die "Output filename not specified! Use the -o|--output flag!";
     }
 
+    require XML::Grammar::Fiction::FromProto;
+    require XML::Grammar::Fiction::FromProto::Parser::QnD;
     my $converter = XML::Grammar::Fiction::FromProto->new(
         {
             parser_class => "XML::Grammar::Fiction::FromProto::Parser::QnD",
@@ -58,12 +57,12 @@ to convert from a well-formed plaintext format to Fiction-XML.
 
 =head1 VERSION
 
-version 0.30.0
+version 0.32.0
 
 =head1 SYNOPSIS
 
     perl -MXML::Grammar::Fiction::App::FromProto -e 'run()' -- \
-	-o "$OUTPUT_FILE" "$INPUT_FILE"
+        -o "$OUTPUT_FILE" "$INPUT_FILE"
 
 =head1 FUNCTIONS
 
