@@ -1,5 +1,5 @@
 package XML::Grammar::FictionBase::TagsTree2XML;
-$XML::Grammar::FictionBase::TagsTree2XML::VERSION = '0.30.0';
+$XML::Grammar::FictionBase::TagsTree2XML::VERSION = '0.32.0';
 use strict;
 use warnings;
 
@@ -7,8 +7,10 @@ use MooX 'late';
 
 use XML::Writer    ();
 use HTML::Entities ();
+use Path::Tiny     qw/ path /;
 
-use Path::Tiny qw/ path /;
+require XML::Grammar::Fiction::FromProto::Parser::QnD;
+require XML::Grammar::Fiction::FromProto::Parser;
 
 sub _get_xml_xml_ns
 {
@@ -504,7 +506,7 @@ Internal - (to settle pod-coverage.).
 
 =head1 VERSION
 
-version 0.30.0
+version 0.32.0
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
