@@ -1,12 +1,10 @@
 package XML::Grammar::Screenplay::API::ImageListDoc;
-$XML::Grammar::Screenplay::API::ImageListDoc::VERSION = '0.30.0';
+$XML::Grammar::Screenplay::API::ImageListDoc::VERSION = '0.32.0';
 use strict;
 use warnings;
 
 use MooX 'late';
 
-use XML::Grammar::Screenplay::FromProto::Parser::QnD ();
-
 extends('XML::Grammar::Screenplay::FromProto');
 
 has ['_dom'] => ( is => 'rw' );
@@ -42,7 +40,7 @@ q{http://web-cpan.berlios.de/modules/XML-Grammar-Screenplay/screenplay-xml-0.2/}
 1;
 
 package XML::Grammar::Screenplay::API::ImageListDoc::_Record;
-$XML::Grammar::Screenplay::API::ImageListDoc::_Record::VERSION = '0.30.0';
+$XML::Grammar::Screenplay::API::ImageListDoc::_Record::VERSION = '0.32.0';
 use MooX 'late';
 
 has '_uri' => ( is => 'ro' );
@@ -69,7 +67,7 @@ __END__
 
 =head1 VERSION
 
-version 0.30.0
+version 0.32.0
 
 =head1 SYNOPSIS
 
@@ -79,6 +77,10 @@ version 0.30.0
 
 =head2 my $aref = $self->list_images()
 
+Returns an array reference containing a list of image-encapsulating objects.
+One can call each object's C<< $image_obj->url() >> method to get its URL as a
+string.
+
 =head2
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
