@@ -1,5 +1,5 @@
 package XML::Grammar::Screenplay::FromProto::API::ListImages;
-$XML::Grammar::Screenplay::FromProto::API::ListImages::VERSION = '0.30.0';
+$XML::Grammar::Screenplay::FromProto::API::ListImages::VERSION = '0.32.0';
 use strict;
 use warnings;
 
@@ -8,12 +8,12 @@ use MooX 'late';
 use XML::LibXML ();
 
 use XML::Grammar::Screenplay::API::ImageListDoc ();
-use XML::Grammar::Screenplay::FromProto         ();
 
 sub calc_doc__from_proto_text
 {
     my ( $self, $args ) = @_;
 
+    require XML::Grammar::Screenplay::FromProto::Parser::QnD;
     my $ret = XML::Grammar::Screenplay::API::ImageListDoc->new(
         {
             parser_class => 'XML::Grammar::Screenplay::FromProto::Parser::QnD',
@@ -32,6 +32,7 @@ sub calc_doc__from_intermediate_xml
 {
     my ( $self, $args ) = @_;
 
+    require XML::Grammar::Screenplay::FromProto::Parser::QnD;
     my $ret = XML::Grammar::Screenplay::API::ImageListDoc->new(
         {
             parser_class => 'XML::Grammar::Screenplay::FromProto::Parser::QnD',
@@ -58,7 +59,7 @@ __END__
 
 =head1 VERSION
 
-version 0.30.0
+version 0.32.0
 
 =head1 SYNOPSIS
 
