@@ -1,5 +1,5 @@
 package XML::Grammar::Screenplay::FromProto::Parser::QnD;
-$XML::Grammar::Screenplay::FromProto::Parser::QnD::VERSION = '0.30.0';
+$XML::Grammar::Screenplay::FromProto::Parser::QnD::VERSION = '0.32.0';
 use strict;
 use warnings;
 
@@ -229,6 +229,14 @@ sub _parse_speech_unit
     # All pluses
     if ( $sayer =~ m{\A\++\z} )
     {
+        if ( not $self->_top_is_saying() )
+        {
+            Carp::confess(
+                sprintf(
+qq{Top element for a "+++:" sayer-syntax is not a saying at line %d},
+                    $self->line_num() )
+            );
+        }
         return { elem => $self->_new_para( [] ), para_end => 0 };
     }
     else
@@ -684,7 +692,7 @@ B<For internal use only>.
 
 =head1 VERSION
 
-version 0.30.0
+version 0.32.0
 
 =head1 METHODS
 
